import uuid

from fastapi import APIRouter, Request, Query
from typing import Annotated, Optional

from app.call_center.schema.mismatch_records import GetMismatchRecordsByIdParam, CreateMismatchRecordsParam, \
    UpdateMismatchRecordsParam
from app.call_center.service.mismatch_records_service import mismatch_records_service
from common.response.response_schema import ResponseModel, response_base
from common.security.jwt_call_center import DependsJwtAuth

router = APIRouter()

@router.get(
    '/result',
    summary='未匹配内容分析结果查询',
    dependencies=[
        DependsJwtAuth,
    ],
)
async def get_mismatch_record(
        request: Request,
        external_id: Annotated[Optional[str], Query(description='外部ID')] = None,
        internal_id: Annotated[Optional[str], Query(description='内部ID')] = None
) -> ResponseModel:
    obj = GetMismatchRecordsByIdParam(
        external_id=external_id,
        internal_id=internal_id,
        org_id=request.user.id
    )
    mismatch_record_select = await mismatch_records_service.get_select_by_id(obj=obj)
    data = None
    if mismatch_record_select:
        data = {
            "status": mismatch_record_select.status,
            "internal_id": mismatch_record_select.id,
            "external_id": mismatch_record_select.external_id,
            "ignore": mismatch_record_select.ignore,
            "llm_ignore": mismatch_record_select.llm_ignore,
            "user_intent": mismatch_record_select.user_intent,
            "similar_reply": mismatch_record_select.similar_reply,
            "keywords": mismatch_record_select.keywords,
            "regular": mismatch_record_select.regular
        }
    return response_base.success(data=data)

@router.post(
    '',
    summary='未匹配内容分析',
    dependencies=[
        DependsJwtAuth
    ],
)
async def create_mismatch_record(obj: CreateMismatchRecordsParam, request: Request) -> ResponseModel:
    id_str = str(uuid.uuid4())
    obj.id = id_str
    obj.org_id = request.user.id
    await mismatch_records_service.create(obj=obj)
    return response_base.success()

@router.post(
    '/update',
    summary='未匹配内容更新',
    dependencies=[
        DependsJwtAuth
    ],
)
async def update_mismatch_record(obj: UpdateMismatchRecordsParam, request: Request) -> ResponseModel:
    obj.org_id = request.user.id
    count = await mismatch_records_service.update_ignore(obj=obj)
    if count > 0:
        return response_base.success()
    return response_base.fail()