#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from datetime import datetime
from uuid import UUID

import sqlalchemy as sa
from sqlalchemy import TIMESTAMP, text

from common.model import Base, id_key_str
from sqlalchemy.dialects import mysql
from sqlalchemy.orm import Mapped, mapped_column


class FormRecords(Base):
    """call record"""

    __tablename__ = 'form_records'

    id: Mapped[id_key_str] = mapped_column()
    created_at: Mapped[datetime | None] = mapped_column(TIMESTAMP, nullable=False, server_default=text('CURRENT_TIMESTAMP'), comment='Create Time | 创建日期')
    updated_at: Mapped[datetime | None] = mapped_column(TIMESTAMP, nullable=False, server_default=text('CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP'), comment='Update Time | 修改日期')
    external_id: Mapped[str] = mapped_column(sa.String(255), default='', sort_order=2, comment='外部id')
    industry_type: Mapped[int] = mapped_column(sa.Integer(), default=0, sort_order=3, comment='评分规则代码 0 通用 1 教育')
    chat_history: Mapped[str] = mapped_column(sa.TEXT(), default='', sort_order=4, comment='通话记录')
    form_data: Mapped[dict | None] = mapped_column(sa.JSON(), default=None, sort_order=12, comment='')
    form_value: Mapped[dict | None] = mapped_column(sa.JSON(), default=None, sort_order=13, comment='')
    org_id: Mapped[int] = mapped_column(sa.BIGINT(), default=0, sort_order=7, comment='机构 ID')
    status: Mapped[int] = mapped_column(mysql.TINYINT(), default=0, sort_order=10, comment='状态 0 入库 1 已判断 2 已回调')
    request_data: Mapped[dict | None] = mapped_column(sa.JSON(), default=None, sort_order=12, comment='')
    response_data: Mapped[dict | None] = mapped_column(sa.JSON(), default=None, sort_order=13, comment='')
