#!/usr/bin/env python3
# -*- coding: utf-8 -*-
from datetime import datetime

import sqlalchemy as sa
from sqlalchemy import BigInteger, TIMESTAMP, text

from common.model import Base, id_key
from sqlalchemy.dialects import mysql
from sqlalchemy.orm import Mapped, mapped_column


class IntentOrg(Base):
    """organization"""

    __tablename__ = 'intent_org'

    id: Mapped[id_key] = mapped_column(BigInteger, primary_key=True)
    created_at: Mapped[datetime | None] = mapped_column(TIMESTAMP, nullable=False, server_default=text('CURRENT_TIMESTAMP'), comment='Create Time | 创建日期')
    updated_at: Mapped[datetime | None] = mapped_column(TIMESTAMP, nullable=False, server_default=text('CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP'), comment='Update Time | 修改日期')
    name: Mapped[str | None] = mapped_column(sa.String(255), default=None, sort_order=2, comment='机构名称')
    api_key: Mapped[str | None] = mapped_column(sa.String(255), default=None, sort_order=3, comment='')
    openai_base: Mapped[str | None] = mapped_column(sa.String(255), default=None, sort_order=4, comment='')
    openai_key: Mapped[str | None] = mapped_column(sa.String(255), default=None, sort_order=5, comment='')
    intent_callback: Mapped[str | None] = mapped_column(sa.String(255), default=None, sort_order=6, comment='意向度结果推送地址')
    mismatch_callback: Mapped[str | None] = mapped_column(sa.String(255), default=None, sort_order=6, comment='未匹配结果推送地址')
    status: Mapped[int] = mapped_column(mysql.TINYINT(), default=0, sort_order=9, comment='状态 1 正常 2 禁用')
    deleted_at: Mapped[datetime | None] = mapped_column(TIMESTAMP, default=None, sort_order=10, comment='Delete Time | 删除日期')
